@@ -3,7 +3,7 @@ from __future__ import unicode_literals
 
 from django.contrib import admin
 
-from django_datawatch.models import Result, CheckExecution
+from django_datawatch.models import Result, CheckExecution, ResultStatusHistory
 
 
 @admin.register(Result)
@@ -17,4 +17,17 @@ class CheckAdmin(admin.ModelAdmin):
 @admin.register(CheckExecution)
 class CheckExecutionAdmin(admin.ModelAdmin):
     list_display = ('slug', 'last_run')
-    search_fields = ('slug', )
+    search_fields = ('slug',)
+
+
+@admin.register(ResultStatusHistory)
+class ResultStatusHistory(admin.ModelAdmin):
+    list_display = (
+        'result',
+        'from_status',
+        'to_status',
+        'created',
+    )
+    autocomplete_fields = ('result',)
+    ordering = ('result', 'created')
+    list_select_related = ['result']
